package Task::BeLike::CADAVIS;
{
  $Task::BeLike::CADAVIS::VERSION = '20111013';
}
# ABSTRACT: Chad's favorites

1;

__END__
=pod

=head1 NAME

Task::BeLike::CADAVIS - Chad's favorites

=head1 VERSION

version 20111013

=head1 AUTHOR

Chad A Davis <chad.a.davis@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Chad A Davis.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

